============
Installation
============

At the command line::

    $ pip install networking-l2gw

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv networking-l2gw
    $ pip install networking-l2gw
